summaryrefslogtreecommitdiff
path: root/vcl/inc/skia
diff options
context:
space:
mode:
Diffstat (limited to 'vcl/inc/skia')
-rw-r--r--vcl/inc/skia/salbmp.hxx2
1 files changed, 1 insertions, 1 deletions
diff --git a/vcl/inc/skia/salbmp.hxx b/vcl/inc/skia/salbmp.hxx
index 05e489643f88..e79fb1cc101d 100644
--- a/vcl/inc/skia/salbmp.hxx
+++ b/vcl/inc/skia/salbmp.hxx
@@ -211,7 +211,7 @@ private:
// Erase() is delayed, just sets these two instead of filling the buffer.
bool mEraseColorSet = false;
Color mEraseColor;
- int mAnyAccessCount = 0; // number of any kind of AcquireAccess() that have not been released
+ int mReadAccessCount = 0; // number of read AcquireAccess() that have not been released
#ifdef DBG_UTIL
int mWriteAccessCount = 0; // number of write AcquireAccess() that have not been released
#endif